Overview
========

Chat protocol includes:

#. Minimizing saving information on Server
#. Hosting conversation between two person
#. Lifetime 1 day

.. toctree::
   :maxdepth: 4
   :titlesonly:

   
   Investigation
   Introduction/index
